@@ -1,5 +1,6 @@
 
 test_that("scrap() function", {
+testthat::skip_on_cran()
 
 expect_equal(
 
@@ -37,6 +38,17 @@ expect_equal(
 
   )
 
+  expect_error(scrap(link = "https://www.imdb.com/chart/top/"))
+
+  expect_error(scrap(node = ".titleColumn a"))
+
+  expect_error(scrap())
+
+  expect_error(scrap(
+    link = www.imdb.com,
+    node = .titleColumn
+  ))
+
 
 
 
