@@ -1,7 +1,7 @@
 
 test_that("table_scrap() function", {
 
-  ##############################################
+testthat::skip_on_cran()
 
 expect_equal(
 
