@@ -1,5 +1,6 @@
 
 test_that("weblink_scrap() function", {
+testthat::skip_on_cran()
 
 expect_equal(
 
@@ -33,7 +34,7 @@ expect_equal(
             1)
 
 
-  expect_error(weblink_scrap(""))
+  expect_error(weblink_scrap())
 
 
   expect_false(!is.character(weblink_scrap("https://www.worldbank.org/en/research")))
